@@ -70,7 +70,7 @@ sub readConfigurationFile ($$)
         next if ( length($line) < 1 );
 
         # Strip trailing comments.
-        if ( $line =~ /([^#]*)\#(.*)/ )
+        if ( $line =~ /(.*)\#(.*)/ )
         {
             $line = $1;
         }
@@ -128,11 +128,7 @@ sub xenRunning ($$)
 
     my $running = 0;
 
-    unless ($CONFIG->{'xm'}) {
-        warn "Couldn't determine Xen toolstack, skipping check for running DomUs."
-            unless $ENV{AS_INSTALLED_TESTING};
-        return 0;
-    }
+    die "Couldn't determine Xen toolstack" unless $CONFIG->{'xm'};
 
     open( CMD, $CONFIG->{'xm'}." list $hostname 2>/dev/null |" ) or
       fail_with_config("Failed to run '".$CONFIG->{'xm'}." list $hostname'", $CONFIG);
@@ -196,7 +192,6 @@ sub findXenToolstack
 
 sub runCommand ($$;$)
 {
-    local $| = 1;
     my ($cmd, $CONFIG, $fail_ok) = (@_);
 
     #
